# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/procurement_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/stock/procurement_group.proto\x12+pro.omni.oms.api.v1.stock.procurement_group\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xac\x01\n\x10ProcurementGroup\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmove_type\x18\x03 \x01(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"x\n\x1dProcurementGroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tmove_type\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1eProcurementGroupCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12X\n\x11procurement_group\x18\x02 \x01(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup"\xf9\x02\n\x1bProcurementGroupReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xff\x01\n\x1cProcurementGroupReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12Y\n\x12procurement_groups\x18\x03 \x03(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup"\xb1\x01\n\x1dProcurementGroupUpdateRequest\x12X\n\x11procurement_group\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1eProcurementGroupUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12X\n\x11procurement_group\x18\x02 \x01(\x0b\x32=.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroup"c\n\x1dProcurementGroupDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"k\n\x1eProcurementGroupDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xeb\x05\n\x17ProcurementGroupService\x12\xb3\x01\n\x16ProcurementGroupCreate\x12J.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupCreateRequest\x1aK.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupCreateResponse"\x00\x12\xad\x01\n\x14ProcurementGroupRead\x12H.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupReadRequest\x1aI.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupReadResponse"\x00\x12\xb3\x01\n\x16ProcurementGroupUpdate\x12J.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupUpdateRequest\x1aK.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupUpdateResponse"\x00\x12\xb3\x01\n\x16ProcurementGroupDelete\x12J.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupDeleteRequest\x1aK.pro.omni.oms.api.v1.stock.procurement_group.ProcurementGroupDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.procurement_group_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PROCUREMENTGROUP"]._serialized_start = 166
    _globals["_PROCUREMENTGROUP"]._serialized_end = 338
    _globals["_PROCUREMENTGROUPCREATEREQUEST"]._serialized_start = 340
    _globals["_PROCUREMENTGROUPCREATEREQUEST"]._serialized_end = 460
    _globals["_PROCUREMENTGROUPCREATERESPONSE"]._serialized_start = 463
    _globals["_PROCUREMENTGROUPCREATERESPONSE"]._serialized_end = 660
    _globals["_PROCUREMENTGROUPREADREQUEST"]._serialized_start = 663
    _globals["_PROCUREMENTGROUPREADREQUEST"]._serialized_end = 1040
    _globals["_PROCUREMENTGROUPREADRESPONSE"]._serialized_start = 1043
    _globals["_PROCUREMENTGROUPREADRESPONSE"]._serialized_end = 1298
    _globals["_PROCUREMENTGROUPUPDATEREQUEST"]._serialized_start = 1301
    _globals["_PROCUREMENTGROUPUPDATEREQUEST"]._serialized_end = 1478
    _globals["_PROCUREMENTGROUPUPDATERESPONSE"]._serialized_start = 1481
    _globals["_PROCUREMENTGROUPUPDATERESPONSE"]._serialized_end = 1678
    _globals["_PROCUREMENTGROUPDELETEREQUEST"]._serialized_start = 1680
    _globals["_PROCUREMENTGROUPDELETEREQUEST"]._serialized_end = 1779
    _globals["_PROCUREMENTGROUPDELETERESPONSE"]._serialized_start = 1781
    _globals["_PROCUREMENTGROUPDELETERESPONSE"]._serialized_end = 1888
    _globals["_PROCUREMENTGROUPSERVICE"]._serialized_start = 1891
    _globals["_PROCUREMENTGROUPSERVICE"]._serialized_end = 2638
# @@protoc_insertion_point(module_scope)
