# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_shipper_delivery_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n/v1/rules/delivery_shipper_delivery_method.proto\x12:pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method\x1a\x11\x63ommon/base.proto"\xb5\x01\n\x1d\x44\x65liveryShipperDeliveryMethod\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1b\n\x13\x64\x65livery_shipper_id\x18\x02 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x9d\x01\n*DeliveryShipperDeliveryMethodCreateRequest\x12\x1b\n\x13\x64\x65livery_shipper_id\x18\x01 \x01(\x05\x12\x1a\n\x12\x64\x65livery_method_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfe\x01\n+DeliveryShipperDeliveryMethodCreateResponse\x12\x83\x01\n delivery_shipper_delivery_method\x18\x01 \x01(\x0b\x32Y.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x86\x03\n(DeliveryShipperDeliveryMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x02\n)DeliveryShipperDeliveryMethodReadResponse\x12\x83\x01\n delivery_shipper_delivery_method\x18\x01 \x03(\x0b\x32Y.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethod\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xea\x01\n*DeliveryShipperDeliveryMethodUpdateRequest\x12\x83\x01\n delivery_shipper_delivery_method\x18\x01 \x01(\x0b\x32Y.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfe\x01\n+DeliveryShipperDeliveryMethodUpdateResponse\x12\x83\x01\n delivery_shipper_delivery_method\x18\x01 \x01(\x0b\x32Y.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethod\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"p\n*DeliveryShipperDeliveryMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"x\n+DeliveryShipperDeliveryMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\x8c\x08\n$DeliveryShipperDeliveryMethodService\x12\xf8\x01\n#DeliveryShipperDeliveryMethodCreate\x12\x66.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodCreateRequest\x1ag.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodCreateResponse"\x00\x12\xf2\x01\n!DeliveryShipperDeliveryMethodRead\x12\x64.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodReadRequest\x1a\x65.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodReadResponse"\x00\x12\xf8\x01\n#DeliveryShipperDeliveryMethodUpdate\x12\x66.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodUpdateRequest\x1ag.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodUpdateResponse"\x00\x12\xf8\x01\n#DeliveryShipperDeliveryMethodDelete\x12\x66.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodDeleteRequest\x1ag.pro.omni.oms.api.v1.rules.delivery_shipper_delivery_method.DeliveryShipperDeliveryMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_shipper_delivery_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSHIPPERDELIVERYMETHOD"]._serialized_start = 131
    _globals["_DELIVERYSHIPPERDELIVERYMETHOD"]._serialized_end = 312
    _globals["_DELIVERYSHIPPERDELIVERYMETHODCREATEREQUEST"]._serialized_start = 315
    _globals["_DELIVERYSHIPPERDELIVERYMETHODCREATEREQUEST"]._serialized_end = 472
    _globals["_DELIVERYSHIPPERDELIVERYMETHODCREATERESPONSE"]._serialized_start = 475
    _globals["_DELIVERYSHIPPERDELIVERYMETHODCREATERESPONSE"]._serialized_end = 729
    _globals["_DELIVERYSHIPPERDELIVERYMETHODREADREQUEST"]._serialized_start = 732
    _globals["_DELIVERYSHIPPERDELIVERYMETHODREADREQUEST"]._serialized_end = 1122
    _globals["_DELIVERYSHIPPERDELIVERYMETHODREADRESPONSE"]._serialized_start = 1125
    _globals["_DELIVERYSHIPPERDELIVERYMETHODREADRESPONSE"]._serialized_end = 1436
    _globals["_DELIVERYSHIPPERDELIVERYMETHODUPDATEREQUEST"]._serialized_start = 1439
    _globals["_DELIVERYSHIPPERDELIVERYMETHODUPDATEREQUEST"]._serialized_end = 1673
    _globals["_DELIVERYSHIPPERDELIVERYMETHODUPDATERESPONSE"]._serialized_start = 1676
    _globals["_DELIVERYSHIPPERDELIVERYMETHODUPDATERESPONSE"]._serialized_end = 1930
    _globals["_DELIVERYSHIPPERDELIVERYMETHODDELETEREQUEST"]._serialized_start = 1932
    _globals["_DELIVERYSHIPPERDELIVERYMETHODDELETEREQUEST"]._serialized_end = 2044
    _globals["_DELIVERYSHIPPERDELIVERYMETHODDELETERESPONSE"]._serialized_start = 2046
    _globals["_DELIVERYSHIPPERDELIVERYMETHODDELETERESPONSE"]._serialized_end = 2166
    _globals["_DELIVERYSHIPPERDELIVERYMETHODSERVICE"]._serialized_start = 2169
    _globals["_DELIVERYSHIPPERDELIVERYMETHODSERVICE"]._serialized_end = 3205
# @@protoc_insertion_point(module_scope)
